netapp_ontap.models.mongo_db_on_san_protection_type API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.mongo_db_on_san_protection_type`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class MongoDbOnSanProtectionTypeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the MongoDbOnSanProtectionType object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `local_rpo GET POST PATCH`

    The local RPO of the application.

    Valid choices:

    - hourly
    - none
  `remote_rpo GET POST`

    The remote RPO of the application.

    Valid choices:

    - none
    - zero